@@ -3,20 +3,24 @@ Simulation module
 """
 
 from .simulation import (
-    calculate_class_2_individuals_best_response,
     extract_total_individuals_and_the_ones_within_target_for_both_classes,
     get_average_simulated_state_probabilities,
-    get_mean_blocking_difference_between_two_systems,
+    get_average_simulated_state_probabilities_from_simulations,
+    get_mean_blocking_difference_using_simulation,
     get_mean_proportion_of_individuals_within_target_for_multiple_runs,
     get_multiple_runs_results,
+    get_multiple_runs_results_from_simulations,
     get_simulated_state_probabilities,
     simulate_model,
 )
 
 from .dists import (
     StateDependentExponential,
+    ServerDependentExponential,
+    StateServerDependentExponential,
     is_state_dependent,
     is_server_dependent,
     is_state_server_dependent,
     get_service_distribution,
+    get_arrival_distribution,
 )
